DATA_DIR = "/usr//share"
LIB_DIR = "/usr//lib"
VERSION = "2.25.91"
PACKAGE = "hamster-applet"
PYTHONDIR = "/usr//lib/python2.5/site-packages"
